=====================================
treeinfo -- Instalable trees metadata
=====================================

.. automodule:: productmd.treeinfo


Classes
=======

.. autoclass:: productmd.treeinfo.TreeInfo
    :members:
    :inherited-members:


.. autoclass:: productmd.treeinfo.Release
    :members:


.. autoclass:: productmd.treeinfo.BaseProduct
    :members:


.. autoclass:: productmd.treeinfo.Variants
    :members:


.. autoclass:: productmd.treeinfo.Variant
    :members:


.. autoclass:: productmd.treeinfo.VariantPaths
    :members:


.. autoclass:: productmd.treeinfo.Images
    :members:


.. autoclass:: productmd.treeinfo.Stage2
    :members:


.. autoclass:: productmd.treeinfo.Media
    :members:


.. autoclass:: productmd.treeinfo.Tree
    :members:


.. autoclass:: productmd.treeinfo.Checksums
    :members:
